Avx2

Struct Avx2 

pub struct Avx2 {
    inner: GeneralPurpose,
    kind: SimdKind,
}
A base64 engine that unconditionally uses AVX2, without runtime detection.

This works in no_std builds. Because it does not check for AVX2 support, it must only be used on a CPU that has it. Only the STANDARD and URL_SAFE alphabets are accelerated, so it is constructed with the Avx2::standard / Avx2::url_safe (checked) or Avx2::standard_unchecked / Avx2::url_safe_unchecked constructors.

Fields

inner: GeneralPurposekind: SimdKind

Implementations

Source

impl Avx2

pub fn standard(config: GeneralPurposeConfig) -> Option<Self>

Create an Avx2 engine for the STANDARD alphabet if the running CPU supports AVX2, else None.

Requires the std feature for the detection; in no_std use Avx2::standard_unchecked.

pub fn url_safe(config: GeneralPurposeConfig) -> Option<Self>

Create an Avx2 engine for the URL_SAFE alphabet if the running CPU supports AVX2, else None.

Requires the std feature for the detection; in no_std use Avx2::url_safe_unchecked.

pub const unsafe fn standard_unchecked(config: GeneralPurposeConfig) -> Self

Create an Avx2 engine for the STANDARD alphabet without checking for AVX2 support.

Safety

The CPU that will run encode/decode must support AVX2. Using the engine on a CPU without AVX2 is undefined behavior.

pub const unsafe fn url_safe_unchecked(config: GeneralPurposeConfig) -> Self

Create an Avx2 engine for the URL_SAFE alphabet without checking for AVX2 support.

Safety

The CPU that will run encode/decode must support AVX2. Using the engine on a CPU without AVX2 is undefined behavior.