pub struct Simd {
inner: GeneralPurpose,
kind: SimdKind,
backend: Backend,
}Expand description
A base64 engine that uses the best SIMD instruction set detected at runtime, falling back to the
scalar GeneralPurpose engine.
Requires the std feature (for runtime CPU-feature detection) and an x86_64 or aarch64
target. On other targets, use GeneralPurpose directly. Only the STANDARD and URL_SAFE
alphabets are accelerated, so it is constructed with Simd::standard / Simd::url_safe.
Fields
inner: GeneralPurposekind: SimdKindbackend: BackendImplementations
Sourceimpl Simd
impl Simd
Sourcepub fn standard(config: GeneralPurposeConfig) -> Self
pub fn standard(config: GeneralPurposeConfig) -> Self
Create a Simd engine for the STANDARD alphabet, detecting the instruction set once.
Sourcepub fn url_safe(config: GeneralPurposeConfig) -> Self
pub fn url_safe(config: GeneralPurposeConfig) -> Self
Create a Simd engine for the URL_SAFE alphabet, detecting the instruction set once.
fn new( kind: SimdKind, alphabet: &Alphabet, config: GeneralPurposeConfig, ) -> Self